==> seahorse-3.16.0.tar.xz: seahorse-3.16.0/seahorse-marshal.h <==

#ifndef __seahorse_marshal_MARSHAL_H__
#define __seahorse_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:STRING,DOUBLE (libseahorse/seahorse-marshal.list:1) */
extern void seahorse_marshal_VOID__STRING_DOUBLE (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);

/* VOID:OBJECT,UINT (libseahorse/seahorse-marshal.list:2) */
extern void seahorse_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

/* VOID:OBJECT,POINTER (libseahorse/seahorse-marshal.list:3) */
extern void seahorse_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* VOID:OBJECT,UINT,POINTER (libseahorse/seahorse-marshal.list:4) */
extern void seahorse_marshal_VOID__OBJECT_UINT_POINTER (GClosure     *closure,
                                                        GValue       *return_value,
                                                        guint         n_param_values,
                                                        const GValue *param_values,
                                                        gpointer      invocation_hint,
                                                        gpointer      marshal_data);

/* VOID:OBJECT,OBJECT (libseahorse/seahorse-marshal.list:5) */
extern void seahorse_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);

G_END_DECLS

#endif /* __seahorse_marshal_MARSHAL_H__ */

==> seahorse_3.20.0.orig.tar.xz: seahorse-3.20.0/seahorse-marshal.h <==

#ifndef __seahorse_marshal_MARSHAL_H__
#define __seahorse_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:STRING,DOUBLE (../libseahorse/seahorse-marshal.list:1) */
extern void seahorse_marshal_VOID__STRING_DOUBLE (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);

/* VOID:OBJECT,UINT (../libseahorse/seahorse-marshal.list:2) */
extern void seahorse_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

/* VOID:OBJECT,POINTER (../libseahorse/seahorse-marshal.list:3) */
extern void seahorse_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* VOID:OBJECT,UINT,POINTER (../libseahorse/seahorse-marshal.list:4) */
extern void seahorse_marshal_VOID__OBJECT_UINT_POINTER (GClosure     *closure,
                                                        GValue       *return_value,
                                                        guint         n_param_values,
                                                        const GValue *param_values,
                                                        gpointer      invocation_hint,
                                                        gpointer      marshal_data);

/* VOID:OBJECT,OBJECT (../libseahorse/seahorse-marshal.list:5) */
extern void seahorse_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);

G_END_DECLS

#endif /* __seahorse_marshal_MARSHAL_H__ */
